==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QAxis.java <==
package io.qt.qt3d.input;


/**
 * <p>Stores QAbstractAxisInputs used to trigger an input event</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qaxis.html">Qt3DInput::QAxis</a></p>
 */
public class QAxis extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxis.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qaxis.html#value-prop">Qt3DInput::QAxis::valueChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="value")
    public final Signal1<@io.qt.QtPrimitiveType Float> valueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAxis(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAxis() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qaxis.html#QAxis">Qt3DInput::QAxis::QAxis(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QAxis(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAxis instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qaxis.html#addInput">Qt3DInput::QAxis::addInput(Qt3DInput::QAbstractAxisInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addInput(io.qt.qt3d.input.QAbstractAxisInput input){
        addInput_native_Qt3DInput_QAbstractAxisInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void addInput_native_Qt3DInput_QAbstractAxisInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qaxis.html#inputs">Qt3DInput::QAxis::inputs()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.input.QAbstractAxisInput> inputs(){
        return inputs_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.input.QAbstractAxisInput> inputs_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qaxis.html#removeInput">Qt3DInput::QAxis::removeInput(Qt3DInput::QAbstractAxisInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeInput(io.qt.qt3d.input.QAbstractAxisInput input){
        removeInput_native_Qt3DInput_QAbstractAxisInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void removeInput_native_Qt3DInput_QAbstractAxisInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qaxis.html#value-prop">Qt3DInput::QAxis::value()const</a></p>
     */
    @io.qt.QtPropertyReader(name="value")
    @io.qt.QtUninvokable
    public final float value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float value_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxis(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxis(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxis instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.2.3-sources.jar: io/qt/qt3d/input/QAxis.java <==
package io.qt.qt3d.input;


/**
 * <p>Stores QAbstractAxisInputs used to trigger an input event</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3dinput-qaxis.html">Qt3DInput::QAxis</a></p>
 */
public class QAxis extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxis.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qaxis.html#value-prop">Qt3DInput::QAxis::valueChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="value")
    public final Signal1<@io.qt.QtPrimitiveType Float> valueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAxis(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAxis() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qaxis.html#QAxis">Qt3DInput::QAxis::QAxis(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QAxis(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAxis instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qaxis.html#addInput">Qt3DInput::QAxis::addInput(Qt3DInput::QAbstractAxisInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addInput(io.qt.qt3d.input.QAbstractAxisInput input){
        addInput_native_Qt3DInput_QAbstractAxisInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void addInput_native_Qt3DInput_QAbstractAxisInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qaxis.html#inputs">Qt3DInput::QAxis::inputs()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.input.QAbstractAxisInput> inputs(){
        return inputs_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.input.QAbstractAxisInput> inputs_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qaxis.html#removeInput">Qt3DInput::QAxis::removeInput(Qt3DInput::QAbstractAxisInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeInput(io.qt.qt3d.input.QAbstractAxisInput input){
        removeInput_native_Qt3DInput_QAbstractAxisInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void removeInput_native_Qt3DInput_QAbstractAxisInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qaxis.html#value-prop">Qt3DInput::QAxis::value()const</a></p>
     */
    @io.qt.QtPropertyReader(name="value")
    @io.qt.QtUninvokable
    public final float value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxis(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxis(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxis instance, QDeclarativeConstructor constructor);
    
}
